@@ -40,7 +40,7 @@ G_BEGIN_DECLS
  * application compile time, rather than from the library linked
  * against at application run time.
  */
-#define GTK_SOURCE_MINOR_VERSION (18)
+#define GTK_SOURCE_MINOR_VERSION (19)
 
 /**
  * GTK_SOURCE_MICRO_VERSION:
@@ -177,6 +177,16 @@ G_BEGIN_DECLS
  */
 #define GTK_SOURCE_VERSION_5_18 (G_ENCODE_VERSION (5, 18))
 
+/**
+ * GTK_SOURCE_VERSION_5_20:
+ *
+ * A macro that evaluates to the 5.20 version of GtkSourceView,
+ * in a format that can be used by the C pre-processor.
+ *
+ * Since: 5.20
+ */
+#define GTK_SOURCE_VERSION_5_20 (G_ENCODE_VERSION (5, 20))
+
 /* Define GTK_SOURCE_VERSION_CUR_STABLE */
 #ifndef __GTK_DOC_IGNORE__
 #  if (GTK_SOURCE_MINOR_VERSION % 2)
@@ -308,6 +318,12 @@ G_BEGIN_DECLS
 # define GTK_SOURCE_AVAILABLE_IN_5_18 _GTK_SOURCE_EXTERN
 #endif
 
+#if GTK_SOURCE_VERSION_MAX_ALLOWED < GTK_SOURCE_VERSION_5_20
+# define GTK_SOURCE_AVAILABLE_IN_5_20 G_UNAVAILABLE(5, 20) _GTK_SOURCE_EXTERN
+#else
+# define GTK_SOURCE_AVAILABLE_IN_5_20 _GTK_SOURCE_EXTERN
+#endif
+
 #endif /* __GTK_DOC_IGNORE__ */
 
 GTK_SOURCE_AVAILABLE_IN_ALL
